;+
;NAME:
; thm_ui_valid_dtype
;PURPOSE:
; get valid datatype names from thm_load_* routines, using the
; valid_names keyword and returns a list of data types that can be
; loaded for each instrument.
;CALLING SEQUENCE:
; datalist = thm_ui_valid_dtype(instrument)
;INPUT:
; none
;OUTPUT:
; datalist = a list of the datatypes that can be loaded
; instrument = the instrument responsible for this datatype, note that
;    if there is no way to get at the valid_names from the thm_load
;    procedure for a given instrument, then the instrument = the
;    datatype. 
; llist = the level of the data, some have 'l1', some have 'l2' some
;         have one for each
;HISTORY:
; 16-jan-2007, jmm, jimm@ssl.berkeley.edu
; 29-jan-2007, jmm, various changes, now station isn't returned, gmag
; and asi output are hard-wired, other changes will ensue when load
; routines are standardized.
; 4-feb-2007, jmm, Rewritten back to the old hard-wired version....
; 5-jul-2007, jmm, Added level information
;$LastChangedBy: kenb-mac $
;$LastChangedDate: 2007-01-26 15:52:34 -0800 (Fri, 26 Jan 2007) $
;$LastChangedRevision: 241 $
;$URL: svn+ssh://thmsvn@ambrosia.ssl.berkeley.edu/repos/thmsoc/trunk/idl/themis/common/thm_ui_valid_dtype.pro $
;-
Function thm_ui_valid_dtype, ilist, llist, instr_in = instr_in
  

  dlist = '' & ilist = 11 & llist = ''
  If(keyword_set(instr_in)) Then dtyp0 = strlowcase(instr_in) Else Begin
    dtyp0 = ['asi', 'ask', 'esa', $
             'efi', 'fbk', 'fft', 'fgm', $
             'fit', 'gmag', 'mom', 'scm', 'sst', 'state', 'bau', 'hsk', 'trg']
  Endelse
  dtyp = 'thm_load_'+dtyp0
  ndtyp = n_elements(dtyp)
  resolve_routine, dtyp, /no_recompile
  For j = 0, ndtyp-1 Do Begin
;First you need the valid levels
    If(dtyp0[j] Eq 'esa') Then Begin
      lvl = 'l1' 
      thm_load_esa_pkt, /valid_names, datatype = vvv
      dlist_j = vvv
      ilist_j = replicate('esa_pkt', n_elements(vvv))
      llist_j = replicate(lvl[0], n_elements(vvv))
      lvl = 'l2'
      thm_load_esa, /valid_names, level = 'l2', datatype = vvv
      dlist_j = [dlist_j, vvv]
      ilist_j = [ilist_j, replicate('esa', n_elements(vvv))]
      llist_j = [llist_j, replicate(lvl[0], n_elements(vvv))]
    Endif Else Begin
      ilist_j = '' & llist_j = '' & dlist_j = ''
      call_procedure, dtyp[j], /valid_names, level = lvl
      nlvl = n_elements(lvl)
      For k = 0, nlvl-1 Do Begin
        call_procedure, dtyp[j], level = lvl[k], /valid_names, datatype = vvv
        If(is_string(vvv)) Then Begin
          dlist_j = [dlist_j, vvv]
          ilist_j = [ilist_j, replicate(dtyp0[j], n_elements(vvv))]
          llist_j = [llist_j, replicate(lvl[k], n_elements(vvv))]
        Endif
      Endfor
      If(n_elements(dlist_j) Gt 1) Then Begin
        dlist_j = dlist_j[1:*]
        ilist_j = ilist_j[1:*]
        llist_j = llist_j[1:*]
      Endif
    Endelse
    If(is_string(dlist_j)) Then Begin
      If(is_string(dlist) Eq 0) Then Begin
        dlist = temporary(dlist_j)
        ilist = temporary(ilist_j)
        llist = temporary(llist_j)
      Endif Else Begin
        dlist = [temporary(dlist), temporary(dlist_j)]
        ilist = [temporary(ilist), temporary(ilist_j)]
        llist = [temporary(llist), temporary(llist_j)]
      Endelse
    Endif
  Endfor
  Return, dlist
End
